==> fuel-ui-0.4.1-3.tgz: package/esm/components/Tag/TagSet.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input } from '@angular/core';
import { NgClass } from '@angular/common';
export let TagSet = class TagSet {
    constructor() {
        this.tags = [];
    }
    ngOnDestroy() {
        this.destroyed = true;
    }
    addTag(tag) {
        this.tags.push(tag);
    }
    removeTag(tag) {
        let index = this.tags.indexOf(tag);
        if (index === -1 || this.destroyed || tag.disabled) {
            return;
        }
        tag.remove.next(tag);
        this.tags.splice(index, 1);
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TagSet.prototype, "tags", void 0);
TagSet = __decorate([
    Component({
        selector: 'tagset',
        directives: [NgClass],
        template: "\n      <span *ngFor=\"let tag of tags\" class=\"label fuel-ui-tag-label\" [ngClass]=\"tag.classMap\">\n          <span [innerHtml]=\"tag.title\"></span>\n          <span class=\"fuel-ui-clickable\" [class.disabled]=\"tag.disabled\" *ngIf=\"tag.removable\" (click)=\"$event.preventDefault(); removeTag(tag);\">\n              <i class=\"fa fa-remove\"></i>\n          </span>\n      </span>\n    "
    }), 
    __metadata('design:paramtypes', [])
], TagSet);

==> fuel-ui-0.4.1-4.tgz: package/esm/components/Tag/TagSet.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Component, Input } from '@angular/core';
import { NgClass } from '@angular/common';
export let TagSet = class TagSet {
    constructor() {
        this.tags = [];
    }
    ngOnDestroy() {
        this.destroyed = true;
    }
    addTag(tag) {
        this.tags.push(tag);
    }
    removeTag(tag) {
        let index = this.tags.indexOf(tag);
        if (index === -1 || this.destroyed || tag.disabled) {
            return;
        }
        tag.remove.next(tag);
        this.tags.splice(index, 1);
    }
};
__decorate([
    Input(), 
    __metadata('design:type', Array)
], TagSet.prototype, "tags", void 0);
TagSet = __decorate([
    Component({
        selector: 'tagset',
        directives: [NgClass],
        template: "\n      <span *ngFor=\"let tag of tags\" class=\"fuel-ui-tag tag\" [ngClass]=\"tag.classMap\">\n          <span [innerHtml]=\"tag.title\"></span>\n          <span class=\"fuel-ui-clickable\" [class.disabled]=\"tag.disabled\" *ngIf=\"tag.removable\" (click)=\"$event.preventDefault(); removeTag(tag);\">\n              <i class=\"fa fa-remove\"></i>\n          </span>\n      </span>\n    "
    }), 
    __metadata('design:paramtypes', [])
], TagSet);
